@@ -566,7 +566,7 @@ int main(int argc, char *argv[])
 		// See if input fd is also set
 		if (FD_ISSET(ifd, &rfd)) {
 			do {
-				if (audit_fgets(event, sizeof(event), ifd)) {
+				if (audit_fgets(event,sizeof(event),ifd) > 0) {
 					if (!transport_ok && remote_ended &&
 						(config.remote_ending_action ==
 								FA_RECONNECT ||
@@ -836,7 +836,7 @@ static int negotiate_credentials (void)
 	if (gethostname(host_name, sizeof(host_name)) != 0) {
 		if (!quiet)
 			syslog (LOG_ERR,
-			"gethostname: host name longer than %ld characters?",
+			"gethostname: host name longer than %lu characters?",
 				sizeof (host_name));
 		return -1;
 	}
