@@ -1,5 +1,5 @@
 /* auparse.h --
- * Copyright 2006-08,2012,2014-17 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2006-08,2012,2014-17 Red Hat Inc.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -41,10 +41,12 @@ typedef void (*auparse_callback_ptr)(auparse_state_t *au,
 
 /* General functions that affect operation of the library */
 auparse_state_t *auparse_init(ausource_t source, const void *b);
+int auparse_new_buffer(auparse_state_t *au, const char *data, size_t data_len);
 int auparse_feed(auparse_state_t *au, const char *data, size_t data_len);
 void auparse_feed_age_events(auparse_state_t *au);
 int auparse_flush_feed(auparse_state_t *au);
 int auparse_feed_has_data(auparse_state_t *au);
+int auparse_feed_has_ready_event(auparse_state_t *au);
 void auparse_add_callback(auparse_state_t *au, auparse_callback_ptr callback,
 			void *user_data, user_destroy user_destroy_func);
 void auparse_set_escape_mode(auparse_state_t *au, auparse_esc_t mode);
@@ -63,10 +65,13 @@ int ausearch_add_timestamp_item(auparse_state_t *au, const char *op, time_t sec,
 				unsigned milli, ausearch_rule_t how);
 int ausearch_add_timestamp_item_ex(auparse_state_t *au, const char *op,
 	time_t sec, unsigned milli, unsigned serial, ausearch_rule_t how);
-int ausearch_add_regex(auparse_state_t *au, const char *expr);
+int ausearch_add_regex(auparse_state_t *au, const char *regexp);
 int ausearch_set_stop(auparse_state_t *au, austop_t where);
 void ausearch_clear(auparse_state_t *au);
 
+/* Function dealing with setting user space configuration items */
+int auparse_set_eoe_timeout (time_t new_tmo);
+
 /* Functions that are part of the auparse_normalize interface */
 
 // This causes the current event to become normalized.
