@@ -34,9 +34,10 @@ AUDIT_HIDDEN_START
 void init_interpretation_list(void);
 int load_interpretation_list(const char *buf);
 void free_interpretation_list(void);
+unsigned int interpretation_list_cnt(void);
 int lookup_type(const char *name);
-const char *interpret(const rnode *r, auparse_esc_t escape_mode);
-void aulookup_destroy_uid_list(void);
+const char *do_interpret(const rnode *r, auparse_esc_t escape_mode);
+void lookup_destroy_uid_list(void);
 void aulookup_destroy_gid_list(void);
 char *au_unescape(char *buf);
 
