@@ -1,5 +1,5 @@
-/* libaudit.h -- 
- * Copyright 2004-2018 Red Hat Inc., Durham, North Carolina.
+/* libaudit.h --
+ * Copyright 2004-2018,2021 Red Hat Inc.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * 
+ *
  * Authors:
  *	Steve Grubb <sgrubb@redhat.com>
  *	Rickard E. (Rik) Faith <faith@redhat.com>
@@ -124,6 +124,7 @@ extern "C" {
 #define AUDIT_APPARMOR_HINT		1504
 #define AUDIT_APPARMOR_STATUS		1505
 #define AUDIT_APPARMOR_ERROR		1506
+#define AUDIT_APPARMOR_KILL		1507
 #endif
 
 #define AUDIT_FIRST_KERN_CRYPTO_MSG	1600
@@ -136,12 +137,18 @@ extern "C" {
 #define AUDIT_INTEGRITY_LAST_MSG	1899
 #ifndef AUDIT_INTEGRITY_DATA
 #define AUDIT_INTEGRITY_DATA		1800 /* Data integrity verification */
-#define AUDIT_INTEGRITY_METADATA 	1801 // Metadata integrity verification
+#define AUDIT_INTEGRITY_METADATA	1801 // Metadata integrity verification
 #define AUDIT_INTEGRITY_STATUS		1802 /* Integrity enable status */
 #define AUDIT_INTEGRITY_HASH		1803 /* Integrity HASH type */
 #define AUDIT_INTEGRITY_PCR		1804 /* PCR invalidation msgs */
 #define AUDIT_INTEGRITY_RULE		1805 /* Policy rule */
 #endif
+#ifndef AUDIT_INTEGRITY_EVM_XATTR
+#define AUDIT_INTEGRITY_EVM_XATTR	1806 /* New EVM-covered xattr */
+#endif
+#ifndef AUDIT_INTEGRITY_POLICY_RULE
+#define AUDIT_INTEGRITY_POLICY_RULE	1807 /* Integrity Policy rule */
+#endif
 
 #define AUDIT_FIRST_ANOM_MSG		2100
 #define AUDIT_LAST_ANOM_MSG		2199
@@ -164,6 +171,9 @@ extern "C" {
 #define AUDIT_ANOM_MOD_ACCT		2116 // Changing an acct
 #define AUDIT_ANOM_ROOT_TRANS		2117 // User became root
 #define AUDIT_ANOM_LOGIN_SERVICE	2118 // Service acct attempted login
+#define AUDIT_ANOM_LOGIN_ROOT		2119 // Root login attempted
+#define AUDIT_ANOM_ORIGIN_FAILURES	2120 // Origin has too many failed login
+#define AUDIT_ANOM_SESSION		2121 // The user session is bad
 
 #define AUDIT_FIRST_ANOM_RESP		2200
 #define AUDIT_LAST_ANOM_RESP		2299
@@ -182,6 +192,7 @@ extern "C" {
 #define AUDIT_RESP_HALT			2212 /* take the system down */
 #define AUDIT_RESP_ORIGIN_BLOCK		2213 /* Address blocked by iptables */
 #define AUDIT_RESP_ORIGIN_BLOCK_TIMED	2214 /* Address blocked for time */
+#define AUDIT_RESP_ORIGIN_UNBLOCK_TIMED	2215 /* Address unblocked from timed */
 
 #define AUDIT_FIRST_USER_LSPP_MSG	2300
 #define AUDIT_LAST_USER_LSPP_MSG	2399
@@ -198,6 +209,7 @@ extern "C" {
 #define AUDIT_USER_MAC_POLICY_LOAD	2310 /* Userspc daemon loaded policy */
 #define AUDIT_ROLE_MODIFY		2311 /* Admin modified a role */
 #define AUDIT_USER_MAC_CONFIG_CHANGE	2312 /* Change made to MAC policy */
+#define AUDIT_USER_MAC_STATUS		2313 /* Userspc daemon enforcing change */
 
 #define AUDIT_FIRST_CRYPTO_MSG		2400
 #define AUDIT_CRYPTO_TEST_USER		2400 /* Crypto test results */
@@ -216,10 +228,11 @@ extern "C" {
 
 #define AUDIT_LAST_CRYPTO_MSG		2499
 
+/* Events for both VMs and container orchestration software */
 #define AUDIT_FIRST_VIRT_MSG		2500
-#define AUDIT_VIRT_CONTROL		2500 /* Start, Pause, Stop VM */
+#define AUDIT_VIRT_CONTROL		2500 /* Start,Pause,Stop VM/container */
 #define AUDIT_VIRT_RESOURCE		2501 /* Resource assignment */
-#define AUDIT_VIRT_MACHINE_ID		2502 /* Binding of label to VM */
+#define AUDIT_VIRT_MACHINE_ID		2502 /* Binding of label to VM/cont */
 #define AUDIT_VIRT_INTEGRITY_CHECK	2503 /* Guest integrity results */
 #define AUDIT_VIRT_CREATE		2504 /* Creation of guest image */
 #define AUDIT_VIRT_DESTROY		2505 /* Destruction of guest image */
@@ -278,6 +291,22 @@ extern "C" {
 #define AUDIT_FANOTIFY		1331 /* Fanotify access decision */
 #endif
 
+#ifndef AUDIT_TIME_INJOFFSET
+#define AUDIT_TIME_INJOFFSET	1332 /* Timekeeping offset injected */
+#endif
+
+#ifndef AUDIT_TIME_ADJNTPVAL
+#define AUDIT_TIME_ADJNTPVAL	1333 /* NTP value adjustment */
+#endif
+
+#ifndef AUDIT_BPF
+#define AUDIT_BPF		1334 /* BPF load/unload */
+#endif
+
+#ifndef AUDIT_EVENT_LISTENER
+#define AUDIT_EVENT_LISTENER		1335 /* audit mcast sock join/part */
+#endif
+
 #ifndef AUDIT_MAC_CALIPSO_ADD
 #define AUDIT_MAC_CALIPSO_ADD	1418 /* NetLabel: add CALIPSO DOI entry */
 #endif
@@ -290,6 +319,10 @@ extern "C" {
 #define AUDIT_ANOM_LINK		1702 /* Suspicious use of file links */
 #endif
 
+#ifndef AUDIT_ANOM_CREAT
+#define AUDIT_ANOM_CREAT            1703 /* Suspicious file creation */
+#endif
+
 /* This is related to the filterkey patch */
 #define AUDIT_KEY_SEPARATOR 0x01
 
@@ -344,6 +377,9 @@ extern "C" {
 #ifndef AUDIT_EXE
 #define AUDIT_EXE 112
 #endif
+#ifndef AUDIT_SADDR_FAM
+#define AUDIT_SADDR_FAM 113
+#endif
 
 #ifndef AUDIT_SESSIONID
 #define AUDIT_SESSIONID 25
@@ -486,7 +522,7 @@ struct audit_reply {
 	struct nlmsgerr         *error;
 	struct audit_sig_info   *signal_info;
 	struct daemon_conf      *conf;
-#ifdef AUDIT_FEATURE_BITMAP_ALL
+#ifdef AUDIT_FEATURE_VERSION
 	struct audit_features	*features;
 #endif
 	};
@@ -527,12 +563,12 @@ struct audit_dispatcher_header {
 typedef enum {
 	MACH_X86=0,
 	MACH_86_64,
-	MACH_IA64,
+	MACH_IA64,	// Deprecated but has to stay
 	MACH_PPC64,
 	MACH_PPC,
 	MACH_S390X,
 	MACH_S390,
-	MACH_ALPHA,
+	MACH_ALPHA,	// Deprecated but has to stay
 	MACH_ARM,
 	MACH_AARCH64,
 	MACH_PPC64LE
@@ -561,6 +597,7 @@ extern int  audit_setloginuid(uid_t uid);
 extern uint32_t audit_get_session(void);
 extern int  audit_detect_machine(void);
 extern int audit_determine_machine(const char *arch);
+extern char *audit_format_signal_info(char *buf, int len, char *op, struct audit_reply *rep, char *res);
 
 /* Translation functions */
 extern int        audit_name_to_field(const char *field);
@@ -602,6 +639,7 @@ extern int  audit_set_rate_limit(int fd, uint32_t limit);
 extern int  audit_set_backlog_limit(int fd, uint32_t limit);
 int audit_set_backlog_wait_time(int fd, uint32_t bwt);
 int audit_reset_lost(int fd);
+int audit_reset_backlog_wait_time_actual(int fd);
 extern int  audit_set_feature(int fd, unsigned feature, unsigned value, unsigned lock);
 extern int  audit_set_loginuid_immutable(int fd);
 
@@ -622,15 +660,15 @@ extern int audit_make_equivalent(int fd, const char *mount_point,
 				const char *subtree);
 
 /* AUDIT_ADD_RULE */
-extern int  audit_add_rule_data(int fd, struct audit_rule_data *rule,
-                                int flags, int action);
+extern int audit_add_rule_data(int fd, struct audit_rule_data *rule,
+                               int flags, int action);
 
 /* AUDIT_DEL_RULE */
-extern int  audit_delete_rule_data(int fd, struct audit_rule_data *rule,
-                                   int flags, int action);
+extern int audit_delete_rule_data(int fd, struct audit_rule_data *rule,
+                                  int flags, int action);
 
 /* The following are for standard formatting of messages */
-extern int audit_value_needs_encoding(const char *str, unsigned int len);
+extern int audit_value_needs_encoding(const char *str, unsigned int size);
 extern char *audit_encode_value(char *final,const char *buf,unsigned int size);
 extern char *audit_encode_nv_string(const char *name, const char *value,
 	unsigned int vlen);
@@ -655,16 +693,21 @@ extern int audit_log_user_command(int audit_fd, int type, const char *command,
         const char *tty, int result);
 
 /* Rule-building helper functions */
-extern int  audit_rule_syscall_data(struct audit_rule_data *rule, int scall);
-extern int  audit_rule_syscallbyname_data(struct audit_rule_data *rule,
+/* Heap-allocates and initializes an audit_rule_data */
+extern struct audit_rule_data *audit_rule_create_data(void);
+/* Initializes an existing audit_rule_data struct */
+extern void audit_rule_init_data(struct audit_rule_data *rule);
+extern int audit_rule_syscall_data(struct audit_rule_data *rule, int scall);
+extern int audit_rule_syscallbyname_data(struct audit_rule_data *rule,
                                           const char *scall);
 /* Note that the following function takes a **, where audit_rule_fieldpair()
  * takes just a *.  That structure may need to be reallocated as a result of
  * adding new fields */
-extern int  audit_rule_fieldpair_data(struct audit_rule_data **rulep,
+extern int audit_rule_fieldpair_data(struct audit_rule_data **rulep,
                                       const char *pair, int flags);
 extern int audit_rule_interfield_comp_data(struct audit_rule_data **rulep,
 					 const char *pair, int flags);
+/* Deallocates the audit_rule_rule object, and any associated resources */
 extern void audit_rule_free_data(struct audit_rule_data *rule);
 
 /* Capability testing functions */
