@@ -388,4 +388,59 @@ _S(384, "pkey_alloc")
 _S(385, "pkey_free")
 _S(386, "pkey_mprotect")
 _S(387, "rseq")
+_S(388, "io_pgetevents")
+_S(392, "semtimedop")
+_S(393, "semget")
+_S(394, "semctl")
+_S(395, "shmget")
+_S(396, "shmctl")
+_S(397, "shmat")
+_S(398, "shmdt")
+_S(399, "msgget")
+_S(400, "msgsnd")
+_S(401, "msgrcv")
+_S(402, "msgctl")
+_S(403, "clock_gettime64")
+_S(404, "clock_settime64")
+_S(405, "clock_adjtime64")
+_S(406, "clock_getres_time64")
+_S(407, "clock_nanosleep_time64")
+_S(408, "timer_gettime64")
+_S(409, "timer_settime64")
+_S(410, "timerfd_gettime64")
+_S(411, "timerfd_settime64")
+_S(412, "utimensat_time64")
+_S(413, "pselect6_time64")
+_S(414, "ppoll_time64")
+_S(416, "io_pgetevents_time64")
+_S(417, "recvmmsg_time64")
+_S(418, "mq_timedsend_time64")
+_S(419, "mq_timedreceive_time64")
+_S(420, "semtimedop_time64")
+_S(421, "rt_sigtimedwait_time64")
+_S(422, "futex_time64")
+_S(423, "sched_rr_get_interval_time64")
+_S(424, "pidfd_send_signal")
+_S(425, "io_uring_setup")
+_S(426, "io_uring_enter")
+_S(427, "io_uring_register")
+_S(428, "open_tree")
+_S(429, "move_mount")
+_S(430, "fsopen")
+_S(431, "fsconfig")
+_S(432, "fsmount")
+_S(433, "fspick")
+_S(434, "pidfd_open")
+_S(435, "clone3")
+_S(436, "close_range")
+_S(437, "openat2")
+_S(438, "pidfd_getfd")
+_S(439, "faccessat2")
+_S(440, "process_madvise")
+_S(441, "epoll_pwait2")
+_S(442, "mount_setattr")
+_S(443, "quotactl_fd")
+_S(444, "landlock_create_ruleset")
+_S(445, "landlock_add_rule")
+_S(446, "landlock_restrict_self")
 
