@@ -961,15 +961,8 @@ int auditd_tcp_listen_init(struct ev_loop *loop, struct daemon_conf *config)
 	int one = 1, rc;
 	int prefer_ipv6 = 0;
 
-	transport = config->transport;
-	ev_periodic_init(&periodic_watcher, periodic_handler,
-			  0, config->tcp_client_max_idle, NULL);
-	periodic_watcher.data = config;
-	if (config->tcp_client_max_idle)
-		ev_periodic_start(loop, &periodic_watcher);
-
 	/* If the port is not set, that means we aren't going to
-	  listen for connections.  */
+	   listen for connections.  */
 	if (config->tcp_listen_port == 0)
 		return 0;
 
@@ -981,7 +974,7 @@ int auditd_tcp_listen_init(struct ev_loop *loop, struct daemon_conf *config)
 
 	rc = getaddrinfo(NULL, local, &hints, &ai);
 	if (rc) {
-        	audit_msg(LOG_ERR, "Cannot lookup addresses");
+		audit_msg(LOG_ERR, "Cannot lookup addresses");
 		return 1;
 	}
 
@@ -1071,6 +1064,14 @@ next_try:
 	if (nlsocks == 0)
 		return -1;
 
+	// Now that we have sockets, start the periodic timers
+	transport = config->transport;
+	ev_periodic_init(&periodic_watcher, periodic_handler,
+			  0, config->tcp_client_max_idle, NULL);
+	periodic_watcher.data = config;
+	if (config->tcp_client_max_idle)
+		ev_periodic_start(loop, &periodic_watcher);
+
 	use_libwrap = config->use_libwrap;
 	auditd_set_ports(config->tcp_client_min_port,
 			config->tcp_client_max_port,
@@ -1123,6 +1124,10 @@ void auditd_tcp_listen_uninit(struct ev_loop *loop, struct daemon_conf *config)
 #ifdef USE_GSSAPI
 	OM_uint32 status;
 #endif
+	/* If the port isn't set, we didn't listen for connections. */
+	if (config->tcp_listen_port == 0)
+		return;
+
 
 	ev_io_stop(loop, &tcp_listen_watcher);
 	while (nlsocks > 0) {
@@ -1155,7 +1160,7 @@ void auditd_tcp_listen_uninit(struct ev_loop *loop, struct daemon_conf *config)
 static void periodic_reconfigure(struct daemon_conf *config)
 {
 	struct ev_loop *loop = ev_default_loop(EVFLAG_AUTO);
-	if (config->tcp_client_max_idle) {
+	if (config->tcp_listen_port && config->tcp_client_max_idle) {
 		ev_periodic_set(&periodic_watcher, ev_now(loop),
 				 config->tcp_client_max_idle, NULL);
 		ev_periodic_start(loop, &periodic_watcher);
